﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace EasyPortal.Web.Weibo
{
    /// <summary>
    /// Persists credential in HttpSessionState
    /// </summary>
    public sealed class SessionCredentialPersistence : ICredentialPersistence
    {
        /// <summary>
        /// The request credential session name.
        /// </summary>
        public const string RequestSessionName = "weibo-requsetCredential";
        /// <summary>
        /// The access credential session name.
        /// </summary>
        public const string AccessSessionName = "weibo-accessCredential";

        /// <summary>
        /// Sets the request credential.
        /// </summary>
        /// <param name="requsetCredential">The request credential.</param>
        public void SetRequest(Credential requsetCredential)
        {
            HttpKits.SetSession<Credential>(RequestSessionName, requsetCredential);
        }

        /// <summary>
        /// Gets the request credential.
        /// </summary>
        /// <returns>
        /// The request credential.
        /// </returns>
        public Credential GetRequest()
        {
            Credential c= HttpKits.GetSession<Credential>(RequestSessionName);
            return c;
        }


        /// <summary>
        /// Clear the request credential.
        /// </summary>
        public void ClearRequest()
        {
            HttpKits.RemoveSession(RequestSessionName);
        }

        /// <summary>
        /// Sets the access credential.
        /// </summary>
        /// <param name="accessCredential">The access credential.</param>
        public void SetAccess(Credential accessCredential)
        {
            HttpKits.SetSession<Credential>(AccessSessionName, accessCredential);
        }


        /// <summary>
        /// Gets the access credential.
        /// </summary>
        /// <returns>
        /// The access credential.
        /// </returns>
        public Credential GetAccess()
        {
            return HttpKits.GetSession<Credential>(AccessSessionName);
        }
    }
}
